@@ -32,7 +32,7 @@ from . import utils as _utils
 from .utils import Build as _build
 from .__errors__ import DatabaseVersionError as _DatabaseVersionError
 
-__version__ = '0.1.9'
+__version__ = '0.2.0'
 __author__ = 'Ismail SEZEN'
 __email__ = 'sezenismail@gmail.com'
 __license__ = 'AGPLv3'
@@ -906,11 +906,12 @@ class Database:
             args, kwargs,
             {'param': '', 'city': '', 'station': '',
              'region': '', 'select': '', 'wide': False,
-             'as_str': False, 'return_type': 'df'})
+             'as_str': False, 'return_type': 'df', 'set_index': False})
 
         wide = args.pop('wide')
         as_str = args.pop('as_str')
         return_type = args.pop('return_type')
+        set_index = args.pop('set_index')
         for k in list(args.keys())[0:4]:
             args[k] = _utils.to_ascii(args[k])
 
@@ -953,7 +954,8 @@ class Database:
             df = df.replace(_np.nan, F)
 
         else:
-            df = df.set_index(cols)
+            if set_index:
+                df = df.set_index(cols)
 
         if return_type != 'df':
             df = df.reset_index()
